==> qt-creator-opensource-src-4.0.0.zip: qt-creator-opensource-src-4.0.0/tests/unit/unittest/mocksenddocumentannotationscallback.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#ifndef MOCKSENDDOCUMENTANNOTATIONSCALLBACK_H
#define MOCKSENDDOCUMENTANNOTATIONSCALLBACK_H

#include <gmock/gmock.h>
#include <gmock/gmock-matchers.h>
#include <gtest/gtest.h>
#include "gtest-qt-printing.h"

class SendDocumentAnnotationsCallback
{
public:
    virtual ~SendDocumentAnnotationsCallback() = default;

    virtual void sendDocumentAnnotations() = 0;
};

class MockSendDocumentAnnotationsCallback : public SendDocumentAnnotationsCallback
{
public:
    MOCK_METHOD0(sendDocumentAnnotations,
                 void());
};

#endif // MOCKSENDDOCUMENTANNOTATIONSCALLBACK_H

==> qt-creator-opensource-src-4.1.0.zip: qt-creator-opensource-src-4.1.0/tests/unit/unittest/mocksenddocumentannotationscallback.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <gmock/gmock.h>
#include <gmock/gmock-matchers.h>
#include <gtest/gtest.h>
#include "gtest-qt-printing.h"

class SendDocumentAnnotationsCallback
{
public:
    virtual ~SendDocumentAnnotationsCallback() = default;

    virtual void sendDocumentAnnotations() = 0;
};

class MockSendDocumentAnnotationsCallback : public SendDocumentAnnotationsCallback
{
public:
    MOCK_METHOD0(sendDocumentAnnotations,
                 void());
};
